==> haskell-regex-posix-0.96.0.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-posix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-posix
version:              0.96.0.0
visibility:           public
id:                   regex-posix-0.96.0.0-7OJz5NVRWC8Iss6JoaXwme
key:                  regex-posix-0.96.0.0-7OJz5NVRWC8Iss6JoaXwme
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2010, Christopher Kuklewicz
maintainer:           hvr@gnu.org
author:               Christopher Kuklewicz
synopsis:             POSIX Backend for "Text.Regex" (regex-base)
description:
    The POSIX regex backend for <//hackage.haskell.org/package/regex-base regex-base>.

    The main appeal of this backend is that it'\''s very lightweight due to its reliance on the ubiquitous <https://pubs.opengroup.org/onlinepubs/9699919799/basedefs/regex.h.html POSIX.2 regex> facility that is provided by the standard C library on most POSIX platforms.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  a3f0cdc147b34f45988649f8bfaa78ee
exposed:              True
exposed-modules:
    Text.Regex.Posix Text.Regex.Posix.ByteString
    Text.Regex.Posix.ByteString.Lazy Text.Regex.Posix.Sequence
    Text.Regex.Posix.String Text.Regex.Posix.Wrap

hidden-modules:       Paths_regex_posix
import-dirs:          /usr/lib/ghc-8.10.5/site-local/regex-posix-0.96.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/regex-posix-0.96.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/regex-posix-0.96.0.0
hs-libraries:         HSregex-posix-0.96.0.0-7OJz5NVRWC8Iss6JoaXwme
depends:
    array-0.5.4.0 base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    regex-base-0.94.0.1-BhcrfAa0EaQLabAeJ8QV4e

haddock-interfaces:   /usr/share/doc/haskell-regex-posix/html/regex-posix.haddock
haddock-html:         /usr/share/doc/haskell-regex-posix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-posix-0.96.0.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-posix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-posix
version:              0.96.0.0
visibility:           public
id:                   regex-posix-0.96.0.0-BaokHlejtNZIX9vLoQOTE0
key:                  regex-posix-0.96.0.0-BaokHlejtNZIX9vLoQOTE0
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2010, Christopher Kuklewicz
maintainer:           hvr@gnu.org
author:               Christopher Kuklewicz
synopsis:             POSIX Backend for "Text.Regex" (regex-base)
description:
    The POSIX regex backend for <//hackage.haskell.org/package/regex-base regex-base>.

    The main appeal of this backend is that it'\''s very lightweight due to its reliance on the ubiquitous <https://pubs.opengroup.org/onlinepubs/9699919799/basedefs/regex.h.html POSIX.2 regex> facility that is provided by the standard C library on most POSIX platforms.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  802f654bc40abbf8f7a760c55680e713
exposed:              True
exposed-modules:
    Text.Regex.Posix Text.Regex.Posix.ByteString
    Text.Regex.Posix.ByteString.Lazy Text.Regex.Posix.Sequence
    Text.Regex.Posix.String Text.Regex.Posix.Wrap

hidden-modules:       Paths_regex_posix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/regex-posix-0.96.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/regex-posix-0.96.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/regex-posix-0.96.0.0
hs-libraries:         HSregex-posix-0.96.0.0-BaokHlejtNZIX9vLoQOTE0
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    regex-base-0.94.0.1-ApKWahF5a61J2tR7Doeu1C

haddock-interfaces:   /usr/share/doc/haskell-regex-posix/html/regex-posix.haddock
haddock-html:         /usr/share/doc/haskell-regex-posix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
